-- Copyright © 2017-2020 Nicolas Mailhot <nim@fedoraproject.org>
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <https://www.gnu.org/licenses/>.
--
-- SPDX-License-Identifier: GPL-3.0-or-later

-- This file contains Lua code used in rpm macros to create rpm packages past
-- the srpm stage: anything starting with %prep.
--
-- The sister file gosrpm.lua deals with srpm and buildroot setup and is more
-- restricted.

local fedora = require "fedora.common"
local     go = require "fedora.srpm.go"

-- %go_prep core
local function prep(suffix, extracted, keepvendor, verbose)
  local  forge = require "fedora.srpm.forge"
  go.env(suffix, verbose)
  if not extracted then
    local fs = fedora.read("go_forge_suffix" .. suffix)
    forge.prep(fs, verbose)
  end
  if not keepvendor then
    print(rpm.expand([[
rm -fr %{_builddir}/%{__current_go_extractdir}/vendor
]]))
  end
end

-- %go_generate_buildrequires core
local function generate_buildrequires(suffix)
  go.env(suffix, false)
  print(rpm.expand([[
%__go_generate_buildrequires
]]))
end

-- %go_build core
local function build(suffix, verbose)
  go.env(suffix, verbose)
  print(rpm.expand([[
%__go_build
]]))
end

-- %go_staging_dir core
local function staging_dir(suffix, verbose)
  go.env(suffix, verbose)
  print(rpm.expand([[
%__go_staging_dir
]]))
end

-- %go_install core
local function install(suffix, verbose)
  go.env(suffix, verbose)
  print(rpm.expand([[
%__go_module_install
%__go_devel_install
%__go_other_install
]]))
end

-- %go_check core
local function check(suffix, verbose)
  go.env(suffix, verbose)
  fedora.set("gomodulesmode", "GO111MODULE=on")
  print(rpm.expand([[
%__go_check
]]))
end

local function module_files()
  print(rpm.expand('%files -n  %{__current_go_module_name} ' ..
                          '-f "%{__current_go_module_list}"\n'))
end

local function devel_files()
  print(rpm.expand('%files -n  %{__current_go_devel_name} ' ..
                          '-f "%{__current_go_devel_list}"\n'))
end

-- Core of %go_files
local function files(suffix, verbose)
  go.env(suffix, verbose)
  module_files()
  print("\n")
  devel_files()
end

return {
  floop                  = go.floop,
  prep                   = prep,
  generate_buildrequires = generate_buildrequires,
  build                  = build,
  staging_dir            = staging_dir,
  install                = install,
  check                  = check,
  files                  = files,
}
